@@ -1,6 +1,3 @@
-import importlib
-import sys
-
 from python_compute_module.query_runner import QueryRunner
 
 
@@ -8,7 +5,6 @@ class ComputeModuleApp:
     def __init__(self):
         self.registered_functions = []
 
-
     def function(self, func):
         self.registered_functions.append(func)
         return func
